<div align="center">



<img src="docs/source/_static/images/logo/intellino_logo.png" width="600" height="300">



**The Intellino core logic wrapper for ML simulation with intellino**

</div>

---



<!-- TABLE OF CONTENTS -->

## Table of Contents



*  [About the Project](#about-the-project)
  * [Built With](#built-with)
* [Getting Started](#getting-started)
  * [Prerequisites](#prerequisites)
  * [Installation](#installation)

*  [Usage](#usage)

*  [Roadmap](#roadmap)

*  [Contributing](#contributing)

* [License](#license)

* [Contact](#contact)

* [Acknowledgements](#acknowledgements)



<!-- ABOUT THE PROJECT -->

##  About The Project



[![Product Name Screen Shot][product-screenshot]](https://example.com)



There are many great README templates available on GitHub, however, I didn't find one that really suit my needs so I created this enhanced one. I want to create a README template so amazing that it'll be the last one you ever need.



Here's why:

* Your time should be focused on creating something amazing. A project that solves a problem and helps others

* You shouldn't be doing the same tasks over and over like creating a README from scratch

* You should element DRY principles to the rest of your life :smile:



Of course, no one template will serve all projects since your needs may be different. So I'll be adding more in the near future. You may also suggest changes by forking this repo and creating a pull request or opening an issue.



A list of commonly used resources that I find helpful are listed in the acknowledgements.



### Built With

This section should list any major frameworks that you built your project using. Leave any add-ons/plugins for the acknowledgements section. Here are a few examples.

- [Bootstrap](https://getbootstrap.com)

- [JQuery](https://jquery.com)

- [Laravel](https://laravel.com)







<!-- GETTING STARTED -->

## Getting Started



This is an example of how you may give instructions on setting up your project locally.

To get a local copy up and running follow these simple example steps.



### Prerequisites



This is an example of how to list things you need to use the software and how to install them.

* npm

```sh
npm install npm@latest -g
```



### Installation



1. Get a free API Key at [https://example.com](https://example.com)

2. Clone the repo

```sh
git clone https://github.com/your_username_/Project-Name.git
```



3. Install NPM packages

```sh
npm install
```



4. Enter your API in `config.js`

```JS
const API_KEY = 'ENTER YOUR API';
```





<!-- USAGE EXAMPLES -->

## Usage



Use this space to show useful examples of how a project can be used. Additional screenshots, code examples and demos work well in this space. You may also link to more resources.



_For more examples, please refer to the [Documentation](https://example.com)_



<!-- ROADMAP -->

## Roadmap



See the [open issues](https://github.com/othneildrew/Best-README-Template/issues) for a list of proposed features (and known issues).







<!-- CONTRIBUTING -->

## Contributing



Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.



1. Fork the Project

2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)

3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)

4. Push to the Branch (`git push origin feature/AmazingFeature`)

5. Open a Pull Request



<!-- LICENSE -->

## License

Distributed under the MIT License. See `LICENSE` for more information.



<!-- CONTACT -->

## Contact

Your Name - [@your_twitter](https://twitter.com/your_username) - email@example.com

Project Link: [https://github.com/your_username/repo_name](https://github.com/your_username/repo_name)



<!-- ACKNOWLEDGEMENTS -->

## Acknowledgements

* [GitHub Emoji Cheat Sheet](https://www.webpagefx.com/tools/emoji-cheat-sheet)

* [Img Shields](https://shields.io)

* [Choose an Open Source License](https://choosealicense.com)

* [GitHub Pages](https://pages.github.com)

* [Animate.css](https://daneden.github.io/animate.css)

* [Loaders.css](https://connoratherton.com/loaders)

* [Slick Carousel](https://kenwheeler.github.io/slick)

* [Smooth Scroll](https://github.com/cferdinandi/smooth-scroll)

* [Sticky Kit](http://leafo.net/sticky-kit)

* [JVectorMap](http://jvectormap.com)

* [Font Awesome](https://fontawesome.com)



<!-- MARKDOWN LINKS & IMAGES -->

<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->

[contributors-shield]: https://img.shields.io/github/contributors/othneildrew/Best-README-Template.svg?style=flat-square
[contributors-url]: https://github.com/othneildrew/Best-README-Template/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/othneildrew/Best-README-Template.svg?style=flat-square
[forks-url]: https://github.com/othneildrew/Best-README-Template/network/members
[stars-shield]: https://img.shields.io/github/stars/othneildrew/Best-README-Template.svg?style=flat-square
[stars-url]: https://github.com/othneildrew/Best-README-Template/stargazers
[issues-shield]: https://img.shields.io/github/issues/othneildrew/Best-README-Template.svg?style=flat-square
[issues-url]: https://github.com/othneildrew/Best-README-Template/issues
[license-shield]: https://img.shields.io/github/license/othneildrew/Best-README-Template.svg?style=flat-square
[license-url]: https://github.com/othneildrew/Best-README-Template/blob/master/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=flat-square&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/othneildrew
[product-screenshot]: images/screenshot.png